%define	upstream_name    Tk
%define upstream_version 804.036

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 6

Summary:    Tk modules for Perl
License:    GPL+ or Artistic
Group:      Development/Perl
Url:        https://metacpan.org/release/%{upstream_name}
Source0:    https://cpan.metacpan.org/modules/by-module/Tk/%{upstream_name}-%{upstream_version}.tar.gz
Patch0:         perl-Tk-widget.patch
# modified version of http://ftp.de.debian.org/debian/pool/main/p/perl-tk/perl-tk_804.027-8.diff.gz
Patch1:     perl-Tk-debian.patch
# fix segfaults as in #235666 because of broken cashing code
Patch2:     perl-Tk-seg.patch
Patch3:     perl-Tk-c99.patch
# Fix STRLEN vs int pointer confusion in Tcl_GetByteArrayFromObj()
# It breaks tests with Perl 5.38 on s390* (BZ#2222638)
Patch4:         perl-Tk-Fix-STRLEN-vs-int-pointer-confusion-in-Tcl_GetByteAr.patch
# Fix build with clang 16
# https://bugs.freebsd.org/bugzilla/show_bug.cgi?id=271521
Patch5:         perl-Tk-Fix-build-with-clang-16.patch
# Avoid using incompatible pointer type in pregcomp2.c
Patch6:         perl-Tk-pregcomp2.c-Avoid-using-incompatible-pointer-type.patch
# Avoid using incompatible pointer type for `old_warn`
# https://github.com/eserte/perl-tk/issues/98
Patch7:         perl-Tk-Avoid-using-incompatible-pointer-type-for-old_warn.patch
# Avoid using incompatible pointer type in function 'GetTextIndex'
# https://github.com/eserte/perl-tk/issues/103
Patch8:         perl-Tk-Fix-incompatible-pointer-type-in-function-GetTextIndex.patch
# (tv) further fix: pTK/Xlib.t is regenerated by "mkVFunc -t x Xlib.h":
Patch9:        further-fixes.diff
Patch10:        fix-build-with-clang-16.diff
Patch20:         80-Fix-STRLEN-vs-int-pointer-confusion-in-Tcl_GetByteAr.patch
Patch21:        gcc-14.patch

BuildRequires: perl(Encode)
BuildRequires: perl(ExtUtils::MakeMaker)
BuildRequires: perl(Test::More)
BuildRequires: perl-devel
BuildRequires: pkgconfig(libjpeg)
BuildRequires: pkgconfig(libpng)
BuildRequires: pkgconfig(x11)
BuildRequires: pkgconfig(xft)
BuildRequires: pkgconfig(fontconfig)
BuildRequires: pkgconfig(libnsl)
Provides:   perl(Tk::TextReindex)
Provides:   perl(Tk::LabRadio)
# to remove on upgrade (misc)
Obsoletes:  perl-Tk-PNG

%package	devel
Summary:    Tk modules for Perl (development package)
Group:      Development/Perl
Requires:   perl-Tk = %{version}-%{release}
%package	doc
Summary:    Tk modules for Perl (documentation package)
Group:      Development/Perl
Requires:   perl-Tk = %{version}-%{release}
%global __requires_exclude perl\\(.*LabEnLabRad\\)

%{?perl_default_filter}

%description
This package provides the modules and Tk code for Perl/Tk,
as written by Nick Ing-Simmons (pTk), John Ousterhout(Tk),
and Ioi Kim Lam(Tix).
It gives you the ability to develop perl applications using the Tk GUI.
It includes the source code for the Tk and Tix elements it uses.
The licences for the various components differ, so check the copyright.

%description	devel
This package provides the modules and Tk code for Perl/Tk,
as written by Nick Ing-Simmons (pTk), John Ousterhout(Tk),
and Ioi Kim Lam(Tix).
It gives you the ability to develop perl applications using the Tk GUI.
It includes the source code for the Tk and Tix elements it uses.
The licences for the various components differ, so check the copyright.

This is the development package.

%description	doc
This package provides the modules and Tk code for Perl/Tk,
as written by Nick Ing-Simmons (pTk), John Ousterhout(Tk),
and Ioi Kim Lam(Tix).
It gives you the ability to develop perl applications using the Tk GUI.
It includes the source code for the Tk and Tix elements it uses.
The licences for the various components differ, so check the copyright.

This is the documentation package.

%prep
%setup -q -n %{upstream_name}-%{upstream_version}
chmod -x pod/Popup.pod Tixish/lib/Tk/balArrow.xbm
# debian patch
#%%patch -P 1 -p1
# patch to fix #235666 ... seems like caching code is broken
%patch -P 2 -p1 -b .seg
%patch -P 3 -p1 -b .c99
%patch -P 4 -p1
%patch -P 5 -p1
%patch -P 6 -p1
%patch -P 7 -p1
%patch -P 8 -p1
%patch -P 9 -p1
 

find . -type f | xargs perl -pi -e 's|^#!.*/bin/perl\S*|#!/usr/bin/perl|'
# Make it lib64 aware, avoid patch
perl -pi -e "s,(/usr/X11(R6|\\*)|\\\$X11|\(\?:)/lib,\1/%{_lib},g" \
  myConfig pTk/mTk/unix/configure
#(peroyvind) --center does no longer seem to be working, obsoleted by -c
perl -pi -e "s#--center#-c#" ./Tk/MMutil.pm

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor XFT=1
%make_build

%install
%make_install
%{__chmod} 644 %{buildroot}%{_mandir}/man3*/*

# Remove unpackaged files, add them if you find a use
# Tie::Watch is packaged separately
rm -f %{buildroot}%{perl_vendorarch}/Tk/prolog.ps
rm -f %{buildroot}%{_mandir}/man1/{ptk{ed,sh},widget}.1*

## compress all .pm files (as using perl-PerlIO-gzip).
#find %{buildroot} -name "*.pm" | xargs gzip -9

# fix rights
find %{buildroot} -name "*.so" -exec chmod u+w {} \;

%files
%doc COPYING Changes INSTALL IO JPEG META.json META.yml MYMETA.yml PNG README VERSIONS demos examples
%{_bindir}/*
%{_mandir}/man*/*
%{perl_vendorarch}/Tk.pm*
%dir %{perl_vendorarch}/Tk
%{perl_vendorarch}/Tie/Watch.pm
%{perl_vendorarch}/Tk/*.pm*
%{perl_vendorarch}/Tk/*.gif
%{perl_vendorarch}/Tk/*.xbm
%{perl_vendorarch}/Tk/*.xpm
%{perl_vendorarch}/Tk/license.terms
%{perl_vendorarch}/Tk/Credits
%{perl_vendorarch}/Tk/DragDrop
%{perl_vendorarch}/Tk/Event
%{perl_vendorarch}/Tk/Menu
%{perl_vendorarch}/Tk/Text
%{perl_vendorarch}/Tk/demos
%{perl_vendorarch}/auto/Tk

%files devel
%doc COPYING Funcs.doc INSTALL
%{perl_vendorarch}/Tk/pTk
%{perl_vendorarch}/Tk/*.def
%{perl_vendorarch}/Tk/*.h
%{perl_vendorarch}/Tk/*.m
%{perl_vendorarch}/Tk/*.t
%{perl_vendorarch}/Tk/typemap

%files doc
%doc COPYING
%{perl_vendorarch}/Tk.pod
%{perl_vendorarch}/Tk/*.pod
%{perl_vendorarch}/Tk/README.Adjust


%changelog
* Sat Aug 24 2024 tv <tv> 804.36.0-6.mga10
+ Revision: 2090444
- Further fix build: a file was regenerated later
- Further fix build
- Fix build
+ neoclust <neoclust>
- Rebuild against new perl

* Thu Nov 30 2023 tv <tv> 804.36.0-5.mga10
+ Revision: 2011577
- Rebuild for perl-5.38

* Tue Jun 07 2022 umeabot <umeabot> 804.36.0-4.mga9
+ Revision: 1862949
- Rebuild for Perl 5.36

* Wed Mar 30 2022 umeabot <umeabot> 804.36.0-3.mga9
+ Revision: 1834173
- Mageia 9 Mass Rebuild

* Mon May 24 2021 tmb <tmb> 804.36.0-2.mga9
+ Revision: 1726309
- rebuild for rebuild for perl-5.34.0

* Thu Feb 25 2021 tv <tv> 804.36.0-1.mga9
+ Revision: 1690385
- update to 804.036

* Sun Dec 13 2020 neoclust <neoclust> 804.35.0-3.mga8
+ Revision: 1656287
- Add pkgconfig(libnsl) as buildrequires

* Thu Jun 18 2020 umeabot <umeabot> 804.35.0-2.mga8
+ Revision: 1595667
- Rebuild for perl 5.32

* Sun Mar 29 2020 tv <tv> 804.35.0-1.mga8
+ Revision: 1562038
- update to 804.035

* Sat Feb 15 2020 umeabot <umeabot> 804.34.0-6.mga8
+ Revision: 1528909
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%makeinstall_std

* Mon Aug 26 2019 tmb <tmb> 804.34.0-5.mga8
+ Revision: 1432746
- rebuild for perl 5.30

* Fri Sep 21 2018 umeabot <umeabot> 804.34.0-4.mga7
+ Revision: 1293893
- Mageia 7 Mass Rebuild

* Sun Aug 05 2018 wally <wally> 804.34.0-3.mga7
+ Revision: 1247589
- rebuild for perl 5.28.0

* Tue Oct 03 2017 tv <tv> 804.34.0-2.mga7
+ Revision: 1167203
- rebuild with fixed rpm for missing autodeps

* Tue Sep 19 2017 tv <tv> 804.34.0-1.mga7
+ Revision: 1155777
- update to 804.034

* Thu Aug 31 2017 pterjan <pterjan> 804.33.0-6.mga7
+ Revision: 1149389
- Rebuild for perl ABI changes

* Sat Jul 22 2017 neoclust <neoclust> 804.33.0-5.mga7
+ Revision: 1126580
- Rebuild against new Perl 5.26

* Sun Jun 19 2016 pterjan <pterjan> 804.33.0-4.mga6
+ Revision: 1035373
- Rebuild for perl 5.22.2

* Fri Feb 12 2016 umeabot <umeabot> 804.33.0-3.mga6
+ Revision: 958139
- Mageia 6 Mass Rebuild

* Fri Jun 26 2015 tv <tv> 804.33.0-2.mga6
+ Revision: 845404
- rebuild for soname-ifed perl

* Tue Jun 23 2015 shlomif <shlomif> 804.33.0-1.mga6
+ Revision: 840798
- New version 804.033 + Rebuild for the new perl

* Wed Oct 15 2014 umeabot <umeabot> 804.32.0-6.mga5
+ Revision: 743432
- Second Mageia 5 Mass Rebuild

* Thu Oct 02 2014 tv <tv> 804.32.0-5.mga5
+ Revision: 736141
- add exclude

* Sun Sep 21 2014 wally <wally> 804.32.0-4.mga5
+ Revision: 706511
- exclude perl(Tk::demos::LabEnLabRad) from requires [Tk/demos/LabEnLabRad.pm is already shipped with perl-Tk, but it mistakenly(?) provides perl(Tk::LabeledEntryLabeledRadiobutton)]

* Tue Sep 16 2014 umeabot <umeabot> 804.32.0-3.mga5
+ Revision: 686716
- Mageia 5 Mass Rebuild

* Tue Jun 03 2014 pterjan <pterjan> 804.32.0-2.mga5
+ Revision: 631820
- Rebuild for perl 5.20

* Mon Feb 24 2014 jquelin <jquelin> 804.32.0-1.mga5
+ Revision: 596461
- update to 804.032

* Sat Oct 19 2013 umeabot <umeabot> 804.31.0-2.mga4
+ Revision: 524134
- Mageia 4 Mass Rebuild

* Wed May 29 2013 tv <tv> 804.31.0-1.mga4
+ Revision: 430181
- new release
- rebuild for new perl

* Sun Jan 13 2013 umeabot <umeabot> 804.30.0-4.mga3
+ Revision: 374381
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Sep 27 2012 shlomif <shlomif> 804.30.0-3.mga3
+ Revision: 298677
- Updated Group to right one. New release - mkrel 3

* Wed May 30 2012 jquelin <jquelin> 804.30.0-2.mga3
+ Revision: 251275
- rebuild for perl 5.16

* Tue Nov 15 2011 jquelin <jquelin> 804.30.0-1.mga2
+ Revision: 167978
- patch renamed
- update to 804.030

* Mon Sep 19 2011 fwang <fwang> 804.29.0-9.mga2
+ Revision: 145228
- rebuild for new libpng

* Mon Sep 05 2011 fwang <fwang> 804.29.0-8.mga2
+ Revision: 138597
- rebuild for updated perl build flags

* Sat Jun 11 2011 sander85 <sander85> 804.29.0-7.mga2
+ Revision: 103877
- perl 5.14

* Sat Feb 26 2011 jquelin <jquelin> 804.29.0-6.mga1
+ Revision: 60550
- perl-tie-watch no longer bundled with perl-tk

* Sat Jan 22 2011 jquelin <jquelin> 804.29.0-5.mga1
+ Revision: 31386
- mageia rebuild
- imported package perl-Tk

